@@ -14,12 +14,21 @@
 # limitations under the License.
 
 
+# 认证失败。
+AUTHFAILURE_AUTHFAILUREERROR = 'AuthFailure.AuthFailureError'
+
 # 鉴权失败，当前用户不允许执行该操作。
 AUTHFAILURE_UNAUTHORIZEDOPERATIONERROR = 'AuthFailure.UnauthorizedOperationError'
 
+# 操作失败。
+FAILEDOPERATION_FAILEDOPERATIONERROR = 'FailedOperation.FailedOperationError'
+
 # 禁止该操作。
 FAILEDOPERATION_NOTALLOWOPERATION = 'FailedOperation.NotAllowOperation'
 
+# 代理出错。
+FAILEDOPERATION_PROXYERROR = 'FailedOperation.ProxyError'
+
 # 任务开始失败。
 FAILEDOPERATION_STARTJOBFAILED = 'FailedOperation.StartJobFailed'
 
@@ -47,12 +56,18 @@ INTERNALERROR_DATABASEERROR = 'InternalError.DatabaseError'
 # 迁移任务冲突。
 INTERNALERROR_DUPLICATEJOB = 'InternalError.DuplicateJob'
 
+# 内部错误。
+INTERNALERROR_INTERNALERRORERROR = 'InternalError.InternalErrorError'
+
 # http请求访问出错。
 INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
 
 # 内部组件访问错误。
 INTERNALERROR_INTERNALINNERCOMMONERROR = 'InternalError.InternalInnerCommonError'
 
+# 调用计费服务失败。
+INTERNALERROR_INTERNALTRADEERROR = 'InternalError.InternalTradeError'
+
 # 锁冲突。
 INTERNALERROR_LOCKERROR = 'InternalError.LockError'
 
@@ -74,6 +89,9 @@ INVALIDPARAMETER_BIZINVALIDPARAMETERVALUEERROR = 'InvalidParameter.BizInvalidPar
 # 实例不存在。
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
+# ip地址错误。
+INVALIDPARAMETER_INVALIDIPADDRESS = 'InvalidParameter.InvalidIpAddress'
+
 # 业务参数错误。
 INVALIDPARAMETERVALUE_BIZINVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.BizInvalidParameterValueError'
 
@@ -101,6 +119,9 @@ OPERATIONDENIED_JOBOPERATIONDENIEDERROR = 'OperationDenied.JobOperationDeniedErr
 # 数据迁移服务不支持当前迁移类型。
 OPERATIONDENIED_MIGRATESERVICESUPPORTERROR = 'OperationDenied.MigrateServiceSupportError'
 
+# 用户余额不足。
+OPERATIONDENIED_NOTENOUGHMONEYERROR = 'OperationDenied.NotEnoughMoneyError'
+
 # 该操作不能执行。
 OPERATIONDENIED_OPERATIONDENIED = 'OperationDenied.OperationDenied'
 
